@@ -15,6 +15,7 @@ def echo_pc_info():
 
     memory_info_str = '''
 操作系统:
+  用户名:     {}
   主机名:     {}
   发行版本:   {}
   内核版本:   {}
@@ -28,9 +29,13 @@ cpu信息:
 内存信息:
 {}
 
+网卡信息:
+{}
+
 磁盘信息:
 {}
         '''.format(
+        os.getlogin(),
         os_info.nodename,
         subprocess.getoutput('cat /etc/issue').strip('\n'),
         os_info.release,
@@ -39,6 +44,7 @@ cpu信息:
         psutil.cpu_count(logical=False),
         psutil.cpu_count(),
         subprocess.getoutput('free -h'),
+        subprocess.getoutput('ip addr'),
         subprocess.getoutput('df -h')
     )
     click.echo(memory_info_str)
